.. _cli:

======================
Command Line Interface
======================

EasyLink is accessed via its command line interface (CLI). This provides a
simple way to interact with the tool and pass in the specification files required
to run a pipeline. 

.. click:: easylink.cli:easylink
   :prog: easylink
   :nested: full
   :commands: run, generate-dag